@@ -73,6 +73,11 @@ HandleButtonEvents::HandleButtonEvents(QObject *parent)
     accel->setGlobalShortcut(globalAction, Qt::Key_PowerOff);
     connect(globalAction, SIGNAL(triggered(bool)), SLOT(powerOffButtonTriggered()));
 
+    globalAction = actionCollection->addAction("PowerDown");
+    globalAction->setText(i18nc("@action:inmenu Global shortcut, used for long presses of the power button", "Power Down"));
+    accel->setGlobalShortcut(globalAction, Qt::Key_PowerDown);
+    connect(globalAction, &QAction::triggered, this, &HandleButtonEvents::powerDownButtonTriggered);
+
     connect(new KScreen::GetConfigOperation(KScreen::GetConfigOperation::NoEDID), &KScreen::ConfigOperation::finished,
             this, [this](KScreen::ConfigOperation *op) {
                 m_screenConfiguration = qobject_cast<KScreen::GetConfigOperation *>(op)->config();
@@ -133,6 +138,9 @@ void HandleButtonEvents::onButtonPressed(BackendInterface::ButtonType type)
         case BackendInterface::PowerButton:
             processAction(m_powerButtonAction);
             break;
+        case BackendInterface::PowerDownButton:
+            processAction(m_powerDownButtonAction);
+            break;
         case BackendInterface::SleepButton:
             processAction(m_sleepButtonAction);
             break;
@@ -189,6 +197,7 @@ bool HandleButtonEvents::loadAction(const KConfigGroup& config)
     m_lidAction = config.readEntry<uint>("lidAction", 0);
     m_triggerLidActionWhenExternalMonitorPresent = config.readEntry<bool>("triggerLidActionWhenExternalMonitorPresent", false);
     m_powerButtonAction = config.readEntry<uint>("powerButtonAction", 0);
+    m_powerDownButtonAction = config.readEntry<uint>("powerDownAction", 0);
 
     checkOutputs();
 
@@ -210,6 +219,11 @@ void HandleButtonEvents::powerOffButtonTriggered()
     onButtonPressed(BackendInterface::PowerButton);
 }
 
+void HandleButtonEvents::powerDownButtonTriggered()
+{
+    onButtonPressed(BackendInterface::PowerDownButton);
+}
+
 void HandleButtonEvents::suspendToDisk()
 {
     onButtonPressed(BackendInterface::HibernateButton);
